@@ -30,7 +30,7 @@ from urllib.parse import ParseResult
 import yaml
 
 import datamodel_code_generator.pydantic_patch  # noqa: F401
-from datamodel_code_generator.format import PythonVersion
+from datamodel_code_generator.format import DatetimeClassType, PythonVersion
 from datamodel_code_generator.model.pydantic_v2 import UnionMode
 from datamodel_code_generator.parser import DefaultPutDict, LiteralType
 from datamodel_code_generator.parser.base import Parser
@@ -81,6 +81,9 @@ def enable_debug_message() -> None:  # pragma: no cover
     pysnooper.tracer.DISABLED = False
 
 
+DEFAULT_MAX_VARIABLE_LENGTH: int = 100
+
+
 def snooper_to_methods(  # type: ignore
     output=None,
     watch=(),
@@ -90,7 +93,7 @@ def snooper_to_methods(  # type: ignore
     overwrite=False,
     thread_info=False,
     custom_repr=(),
-    max_variable_length=100,
+    max_variable_length: Optional[int] = DEFAULT_MAX_VARIABLE_LENGTH,
 ) -> Callable[..., Any]:
     def inner(cls: Type[T]) -> Type[T]:
         if not pysnooper:
@@ -108,7 +111,9 @@ def snooper_to_methods(  # type: ignore
                 overwrite,
                 thread_info,
                 custom_repr,
-                max_variable_length,
+                max_variable_length
+                if max_variable_length is not None
+                else DEFAULT_MAX_VARIABLE_LENGTH,
             )(method)
             setattr(cls, name, snooper_method)
         return cls
@@ -231,7 +236,7 @@ def get_first_file(path: Path) -> Path:  # pragma: no cover
 
 
 def generate(
-    input_: Union[Path, str, ParseResult],
+    input_: Union[Path, str, ParseResult, Mapping[str, Any]],
     *,
     input_filename: Optional[str] = None,
     input_file_type: InputFileType = InputFileType.Auto,
@@ -301,6 +306,9 @@ def generate(
     treat_dots_as_module: bool = False,
     use_exact_imports: bool = False,
     union_mode: Optional[UnionMode] = None,
+    output_datetime_class: Optional[DatetimeClassType] = None,
+    keyword_only: bool = False,
+    no_alias: bool = False,
 ) -> None:
     remote_text_cache: DefaultPutDict[str, str] = DefaultPutDict()
     if isinstance(input_, str):
@@ -351,6 +359,8 @@ def generate(
         parser_class = JsonSchemaParser
 
         if input_file_type in RAW_DATA_TYPES:
+            import json
+
             try:
                 if isinstance(input_, Path) and input_.is_dir():  # pragma: no cover
                     raise Error(f'Input must be a file for {input_file_type}')
@@ -369,15 +379,33 @@ def generate(
                         import io
 
                         obj = get_header_and_first_line(io.StringIO(input_text))
-                else:
+                elif input_file_type == InputFileType.Yaml:
                     obj = load_yaml(
                         input_.read_text(encoding=encoding)  # type: ignore
                         if isinstance(input_, Path)
                         else input_text
                     )
+                elif input_file_type == InputFileType.Json:
+                    obj = json.loads(
+                        input_.read_text(encoding=encoding)  # type: ignore
+                        if isinstance(input_, Path)
+                        else input_text
+                    )
+                elif input_file_type == InputFileType.Dict:
+                    import ast
+
+                    # Input can be a dict object stored in a python file
+                    obj = (
+                        ast.literal_eval(
+                            input_.read_text(encoding=encoding)  # type: ignore
+                        )
+                        if isinstance(input_, Path)
+                        else input_
+                    )
+                else:  # pragma: no cover
+                    raise Error(f'Unsupported input file type: {input_file_type}')
             except:  # noqa
                 raise Error('Invalid file format')
-            import json
 
             from genson import SchemaBuilder
 
@@ -395,11 +423,16 @@ def generate(
             raise Error('union_mode is only supported for pydantic_v2.BaseModel')
     else:
         default_field_extras = None
+
     from datamodel_code_generator.model import get_data_model_types
 
-    data_model_types = get_data_model_types(output_model_type, target_python_version)
+    data_model_types = get_data_model_types(
+        output_model_type, target_python_version, output_datetime_class
+    )
+    source = input_text or input_
+    assert not isinstance(source, Mapping)
     parser = parser_class(
-        source=input_text or input_,
+        source=source,
         data_model_type=data_model_types.data_model,
         data_model_root_type=data_model_types.root_model,
         data_model_field_type=data_model_types.field_model,
@@ -471,6 +504,9 @@ def generate(
         treat_dots_as_module=treat_dots_as_module,
         use_exact_imports=use_exact_imports,
         default_field_extras=default_field_extras,
+        target_datetime_class=output_datetime_class,
+        keyword_only=keyword_only,
+        no_alias=no_alias,
         **kwargs,
     )
 
@@ -481,7 +517,11 @@ def generate(
             input_filename = '<stdin>'
         elif isinstance(input_, ParseResult):
             input_filename = input_.geturl()
+        elif input_file_type == InputFileType.Dict:
+            # input_ might be a dict object provided directly, and missing a name field
+            input_filename = getattr(input_, 'name', '<dict>')
         else:
+            assert isinstance(input_, Path)
             input_filename = input_.name
     if not results:
         raise Error('Models not found in the input data')
