@@ -6,7 +6,7 @@ from operator import attrgetter
 from typing import TYPE_CHECKING
 
 from datamodel_code_generator import DataModelType, InputFileType, OpenAPIScope
-from datamodel_code_generator.format import PythonVersion
+from datamodel_code_generator.format import DatetimeClassType, PythonVersion
 from datamodel_code_generator.model.pydantic_v2 import UnionMode
 from datamodel_code_generator.parser import LiteralType
 from datamodel_code_generator.types import StrictTypes
@@ -98,7 +98,7 @@ base_options.add_argument(
 # ======================================================================================
 model_options.add_argument(
     '--allow-extra-fields',
-    help='Allow to pass extra fields, if this flag is not passed, extra fields are forbidden.',
+    help='Allow passing extra fields, if this flag is not passed, extra fields are forbidden.',
     action='store_true',
     default=None,
 )
@@ -150,6 +150,12 @@ model_options.add_argument(
     action='store_true',
     default=None,
 )
+model_options.add_argument(
+    '--keyword-only',
+    help='Defined models as keyword only (for example dataclass(kw_only=True)).',
+    action='store_true',
+    default=None,
+)
 model_options.add_argument(
     '--reuse-model',
     help='Reuse models on the field when a module has the model with the same content',
@@ -192,6 +198,13 @@ model_options.add_argument(
     action='store_true',
     default=False,
 )
+model_options.add_argument(
+    '--output-datetime-class',
+    help='Choose Datetime class between AwareDatetime, NaiveDatetime or datetime. '
+    'Each output model has its default mapping (for example pydantic: datetime, dataclass: str, ...)',
+    choices=[i.value for i in DatetimeClassType],
+    default=None,
+)
 
 # ======================================================================================
 # Typing options for generated models
@@ -368,6 +381,13 @@ field_options.add_argument(
     choices=[u.value for u in UnionMode],
     default=None,
 )
+field_options.add_argument(
+    '--no-alias',
+    help="""Do not add a field alias. E.g., if --snake-case-field is used along with a base class, which has an 
+            alias_generator""",
+    action='store_true',
+    default=None,
+)
 
 # ======================================================================================
 # Options for templating output
