@@ -14,7 +14,7 @@ class Import(BaseModel):
     reference_path: Optional[str] = None
 
     @classmethod
-    @lru_cache()
+    @lru_cache
     def from_full_path(cls, class_path: str) -> Import:
         split_class_path: List[str] = class_path.split('.')
         return Import(
@@ -43,7 +43,7 @@ class Imports(DefaultDict[Optional[str], Set[str]]):
 
     def create_line(self, from_: Optional[str], imports: Set[str]) -> str:
         if from_:
-            return f"from {from_} import {', '.join(self._set_alias(from_, imports))}"
+            return f'from {from_} import {", ".join(self._set_alias(from_, imports))}'
         return '\n'.join(f'import {i}' for i in self._set_alias(from_, imports))
 
     def dump(self) -> str:
@@ -117,9 +117,11 @@ IMPORT_DICT = Import.from_full_path('typing.Dict')
 IMPORT_DECIMAL = Import.from_full_path('decimal.Decimal')
 IMPORT_DATE = Import.from_full_path('datetime.date')
 IMPORT_DATETIME = Import.from_full_path('datetime.datetime')
+IMPORT_TIMEDELTA = Import.from_full_path('datetime.timedelta')
 IMPORT_PATH = Import.from_full_path('pathlib.Path')
 IMPORT_TIME = Import.from_full_path('datetime.time')
 IMPORT_UUID = Import.from_full_path('uuid.UUID')
 IMPORT_PENDULUM_DATE = Import.from_full_path('pendulum.Date')
 IMPORT_PENDULUM_DATETIME = Import.from_full_path('pendulum.DateTime')
+IMPORT_PENDULUM_DURATION = Import.from_full_path('pendulum.Duration')
 IMPORT_PENDULUM_TIME = Import.from_full_path('pendulum.Time')
