@@ -1,12 +1,19 @@
 from __future__ import annotations
 
+import sys
 from typing import TYPE_CHECKING, Callable, Iterable, List, NamedTuple, Optional, Type
 
+from .. import DatetimeClassType, PythonVersion
 from ..types import DataTypeManager as DataTypeManagerABC
 from .base import ConstraintsBase, DataModel, DataModelFieldBase
 
 if TYPE_CHECKING:
-    from .. import DataModelType, PythonVersion
+    from .. import DataModelType
+
+DEFAULT_TARGET_DATETIME_CLASS = DatetimeClassType.Datetime
+DEFAULT_TARGET_PYTHON_VERSION = PythonVersion(
+    f'{sys.version_info.major}.{sys.version_info.minor}'
+)
 
 
 class DataModelSet(NamedTuple):
@@ -19,12 +26,16 @@ class DataModelSet(NamedTuple):
 
 
 def get_data_model_types(
-    data_model_type: DataModelType, target_python_version: PythonVersion
+    data_model_type: DataModelType,
+    target_python_version: PythonVersion = DEFAULT_TARGET_PYTHON_VERSION,
+    target_datetime_class: Optional[DatetimeClassType] = None,
 ) -> DataModelSet:
     from .. import DataModelType
     from . import dataclass, msgspec, pydantic, pydantic_v2, rootmodel, typed_dict
     from .types import DataTypeManager
 
+    if target_datetime_class is None:
+        target_datetime_class = DEFAULT_TARGET_DATETIME_CLASS
     if data_model_type == DataModelType.PydanticBaseModel:
         return DataModelSet(
             data_model=pydantic.BaseModel,
@@ -46,18 +57,22 @@ def get_data_model_types(
             data_model=dataclass.DataClass,
             root_model=rootmodel.RootModel,
             field_model=dataclass.DataModelField,
-            data_type_manager=DataTypeManager,
+            data_type_manager=dataclass.DataTypeManager,
             dump_resolve_reference_action=None,
         )
     elif data_model_type == DataModelType.TypingTypedDict:
         return DataModelSet(
-            data_model=typed_dict.TypedDict
-            if target_python_version.has_typed_dict
-            else typed_dict.TypedDictBackport,
+            data_model=(
+                typed_dict.TypedDict
+                if target_python_version.has_typed_dict
+                else typed_dict.TypedDictBackport
+            ),
             root_model=rootmodel.RootModel,
-            field_model=typed_dict.DataModelField
-            if target_python_version.has_typed_dict_non_required
-            else typed_dict.DataModelFieldBackport,
+            field_model=(
+                typed_dict.DataModelField
+                if target_python_version.has_typed_dict_non_required
+                else typed_dict.DataModelFieldBackport
+            ),
             data_type_manager=DataTypeManager,
             dump_resolve_reference_action=None,
         )
@@ -66,7 +81,7 @@ def get_data_model_types(
             data_model=msgspec.Struct,
             root_model=msgspec.RootModel,
             field_model=msgspec.DataModelField,
-            data_type_manager=DataTypeManager,
+            data_type_manager=msgspec.DataTypeManager,
             dump_resolve_reference_action=None,
             known_third_party=['msgspec'],
         )
