@@ -225,6 +225,7 @@ class BaseModelBase(DataModel, ABC):
         description: Optional[str] = None,
         default: Any = UNDEFINED,
         nullable: bool = False,
+        keyword_only: bool = False,
     ) -> None:
         methods: List[str] = [field.method for field in fields if field.method]
 
@@ -241,6 +242,7 @@ class BaseModelBase(DataModel, ABC):
             description=description,
             default=default,
             nullable=nullable,
+            keyword_only=keyword_only,
         )
 
     @cached_property
@@ -275,6 +277,7 @@ class BaseModel(BaseModelBase):
         description: Optional[str] = None,
         default: Any = UNDEFINED,
         nullable: bool = False,
+        keyword_only: bool = False,
     ) -> None:
         super().__init__(
             reference=reference,
@@ -288,6 +291,7 @@ class BaseModel(BaseModelBase):
             description=description,
             default=default,
             nullable=nullable,
+            keyword_only=keyword_only,
         )
         config_parameters: Dict[str, Any] = {}
 
@@ -318,4 +322,4 @@ class BaseModel(BaseModelBase):
         if config_parameters:
             from datamodel_code_generator.model.pydantic import Config
 
-            self.extra_template_data['config'] = Config.parse_obj(config_parameters)
+            self.extra_template_data['config'] = Config.parse_obj(config_parameters)  # pyright: ignore [reportArgumentType]
