@@ -46,6 +46,7 @@ except ImportError:  # pragma: no cover
         "Please run `$pip install 'datamodel-code-generator[graphql]`' to generate data-model from a GraphQL schema."
     )
 
+from datamodel_code_generator.format import DatetimeClassType
 
 graphql_resolver = graphql.type.introspection.TypeResolvers()
 
@@ -157,6 +158,9 @@ class GraphQLParser(Parser):
         treat_dots_as_module: bool = False,
         use_exact_imports: bool = False,
         default_field_extras: Optional[Dict[str, Any]] = None,
+        target_datetime_class: DatetimeClassType = DatetimeClassType.Datetime,
+        keyword_only: bool = False,
+        no_alias: bool = False,
     ) -> None:
         super().__init__(
             source=source,
@@ -227,6 +231,9 @@ class GraphQLParser(Parser):
             treat_dots_as_module=treat_dots_as_module,
             use_exact_imports=use_exact_imports,
             default_field_extras=default_field_extras,
+            target_datetime_class=target_datetime_class,
+            keyword_only=keyword_only,
+            no_alias=no_alias,
         )
 
         self.data_model_scalar_type = data_model_scalar_type
@@ -366,7 +373,7 @@ class GraphQLParser(Parser):
     def parse_field(
         self,
         field_name: str,
-        alias: str,
+        alias: Optional[str],
         field: Union[graphql.GraphQLField, graphql.GraphQLInputField],
     ) -> DataModelFieldBase:
         final_data_type = DataType(
@@ -392,9 +399,9 @@ class GraphQLParser(Parser):
             elif graphql.is_non_null_type(obj):  # pragma: no cover
                 data_type.is_optional = False
 
-            obj = obj.of_type
+            obj = obj.of_type  # pyright: ignore [reportAttributeAccessIssue]
 
-        data_type.type = obj.name
+        data_type.type = obj.name  # pyright: ignore [reportAttributeAccessIssue]
 
         required = (not self.force_optional_for_required_fields) and (
             not final_data_type.is_optional
@@ -449,7 +456,7 @@ class GraphQLParser(Parser):
 
         base_classes = []
         if hasattr(obj, 'interfaces'):  # pragma: no cover
-            base_classes = [self.references[i.name] for i in obj.interfaces]
+            base_classes = [self.references[i.name] for i in obj.interfaces]  # pyright: ignore [reportAttributeAccessIssue]
 
         data_model_type = self.data_model_type(
             reference=self.references[obj.name],
@@ -460,6 +467,7 @@ class GraphQLParser(Parser):
             extra_template_data=self.extra_template_data,
             path=self.current_source_path,
             description=obj.description,
+            keyword_only=self.keyword_only,
         )
         self.results.append(data_model_type)
 
