@@ -71,6 +71,8 @@ from datamodel_code_generator.util import (
 if PYDANTIC_V2:
     from pydantic import ConfigDict
 
+from datamodel_code_generator.format import DatetimeClassType
+
 
 def get_model_by_path(
     schema: Union[Dict[str, Any], List[Any]], keys: Union[List[str], List[int]]
@@ -116,6 +118,7 @@ json_schema_data_formats: Dict[str, Dict[str, Types]] = {
         'binary': Types.binary,
         'date': Types.date,
         'date-time': Types.date_time,
+        'duration': Types.timedelta,
         'time': Types.time,
         'password': Types.password,
         'path': Types.path,
@@ -255,7 +258,7 @@ class JsonSchemaObject(BaseModel):
     extras: Dict[str, Any] = Field(alias=__extra_key__, default_factory=dict)
     discriminator: Union[Discriminator, str, None] = None
     if PYDANTIC_V2:
-        model_config = ConfigDict(
+        model_config = ConfigDict(  # pyright: ignore [reportPossiblyUnboundVariable]
             arbitrary_types_allowed=True,
             ignored_types=(cached_property,),
         )
@@ -317,7 +320,7 @@ class JsonSchemaObject(BaseModel):
         return isinstance(self.type, list) and 'null' in self.type
 
 
-@lru_cache()
+@lru_cache
 def get_ref_type(ref: str) -> JSONReference:
     if ref[0] == '#':
         return JSONReference.LOCAL
@@ -335,7 +338,7 @@ def _get_type(type_: str, format__: Optional[str] = None) -> Types:
     if data_formats is not None:
         return data_formats
 
-    warn(f'format of {format__!r} not understood for {type_!r} - using default' '')
+    warn(f'format of {format__!r} not understood for {type_!r} - using default')
     return json_schema_data_formats[type_]['default']
 
 
@@ -357,7 +360,7 @@ EXCLUDE_FIELD_KEYS_IN_JSON_SCHEMA: Set[str] = {
 }
 
 EXCLUDE_FIELD_KEYS = (
-    set(JsonSchemaObject.get_fields())
+    set(JsonSchemaObject.get_fields())  # pyright: ignore [reportAttributeAccessIssue]
     - DEFAULT_FIELD_KEYS
     - EXCLUDE_FIELD_KEYS_IN_JSON_SCHEMA
 ) | {
@@ -443,6 +446,9 @@ class JsonSchemaParser(Parser):
         treat_dots_as_module: bool = False,
         use_exact_imports: bool = False,
         default_field_extras: Optional[Dict[str, Any]] = None,
+        target_datetime_class: DatetimeClassType = DatetimeClassType.Datetime,
+        keyword_only: bool = False,
+        no_alias: bool = False,
     ) -> None:
         super().__init__(
             source=source,
@@ -513,13 +519,16 @@ class JsonSchemaParser(Parser):
             treat_dots_as_module=treat_dots_as_module,
             use_exact_imports=use_exact_imports,
             default_field_extras=default_field_extras,
+            target_datetime_class=target_datetime_class,
+            keyword_only=keyword_only,
+            no_alias=no_alias,
         )
 
         self.remote_object_cache: DefaultPutDict[str, Dict[str, Any]] = DefaultPutDict()
         self.raw_obj: Dict[Any, Any] = {}
         self._root_id: Optional[str] = None
         self._root_id_base_path: Optional[str] = None
-        self.reserved_refs: DefaultDict[Tuple[str], Set[str]] = defaultdict(set)
+        self.reserved_refs: DefaultDict[Tuple[str, ...], Set[str]] = defaultdict(set)
         self.field_keys: Set[str] = {
             *DEFAULT_FIELD_KEYS,
             *self.field_extra_keys,
@@ -611,6 +620,7 @@ class JsonSchemaParser(Parser):
             use_default_kwarg=self.use_default_kwarg,
             original_name=original_field_name,
             has_default=field.has_default,
+            type_has_null=field.type_has_null,
         )
 
     def get_data_type(self, obj: JsonSchemaObject) -> DataType:
@@ -803,6 +813,7 @@ class JsonSchemaParser(Parser):
             extra_template_data=self.extra_template_data,
             path=self.current_source_path,
             description=obj.description if self.use_schema_description else None,
+            keyword_only=self.keyword_only,
         )
         self.results.append(data_model_type)
 
@@ -1046,6 +1057,7 @@ class JsonSchemaParser(Parser):
             path=self.current_source_path,
             description=obj.description if self.use_schema_description else None,
             nullable=obj.type_has_null,
+            keyword_only=self.keyword_only,
         )
         self.results.append(data_model_type)
         return self.data_type(reference=reference)
@@ -1706,6 +1718,9 @@ class JsonSchemaParser(Parser):
     def parse_raw(self) -> None:
         for source, path_parts in self._get_context_source_path_parts():
             self.raw_obj = load_yaml(source.text)
+            if self.raw_obj is None:  # pragma: no cover
+                warn(f'{source.path} is empty. Skipping this file')
+                continue
             if self.custom_class_name_generator:
                 obj_name = self.raw_obj.get('title', 'Model')
             else:
@@ -1783,6 +1798,7 @@ class JsonSchemaParser(Parser):
                 root_obj = self.SCHEMA_OBJECT_TYPE.parse_obj(raw)
                 self.parse_id(root_obj, path_parts)
                 definitions: Optional[Dict[Any, Any]] = None
+                schema_path = ''
                 for schema_path, split_schema_path in self.schema_paths:
                     try:
                         definitions = get_model_by_path(raw, split_schema_path)
