@@ -36,6 +36,7 @@ from datamodel_code_generator import (
     load_yaml,
     snooper_to_methods,
 )
+from datamodel_code_generator.format import DatetimeClassType
 from datamodel_code_generator.model import DataModel, DataModelFieldBase
 from datamodel_code_generator.model import pydantic as pydantic_model
 from datamodel_code_generator.parser.base import get_special_path
@@ -225,6 +226,9 @@ class OpenAPIParser(JsonSchemaParser):
         treat_dots_as_module: bool = False,
         use_exact_imports: bool = False,
         default_field_extras: Optional[Dict[str, Any]] = None,
+        target_datetime_class: DatetimeClassType = DatetimeClassType.Datetime,
+        keyword_only: bool = False,
+        no_alias: bool = False,
     ):
         super().__init__(
             source=source,
@@ -295,6 +299,9 @@ class OpenAPIParser(JsonSchemaParser):
             treat_dots_as_module=treat_dots_as_module,
             use_exact_imports=use_exact_imports,
             default_field_extras=default_field_extras,
+            target_datetime_class=target_datetime_class,
+            keyword_only=keyword_only,
+            no_alias=no_alias,
         )
         self.open_api_scopes: List[OpenAPIScope] = openapi_scopes or [
             OpenAPIScope.Schemas
@@ -309,8 +316,10 @@ class OpenAPIParser(JsonSchemaParser):
         return get_model_by_path(ref_body, ref_path.split('/')[1:])
 
     def get_data_type(self, obj: JsonSchemaObject) -> DataType:
-        # OpenAPI doesn't allow `null` in `type` field and list of types
+        # OpenAPI 3.0 doesn't allow `null` in the `type` field and list of types
         # https://swagger.io/docs/specification/data-models/data-types/#null
+        # OpenAPI 3.1 does allow `null` in the `type` field and is equivalent to
+        # a `nullable` flag on the property itself
         if obj.nullable and self.strict_nullable and isinstance(obj.type, str):
             obj.type = [obj.type, 'null']
 
@@ -358,7 +367,7 @@ class OpenAPIParser(JsonSchemaParser):
         for (
             media_type,
             media_obj,
-        ) in request_body.content.items():  # type: str, MediaObject
+        ) in request_body.content.items():
             if isinstance(media_obj.schema_, JsonSchemaObject):
                 self.parse_schema(name, media_obj.schema_, [*path, media_type])
 
@@ -391,11 +400,13 @@ class OpenAPIParser(JsonSchemaParser):
                 if not object_schema:  # pragma: no cover
                     continue
                 if isinstance(object_schema, JsonSchemaObject):
-                    data_types[status_code][content_type] = self.parse_schema(
-                        name, object_schema, [*path, str(status_code), content_type]
+                    data_types[status_code][content_type] = self.parse_schema(  # pyright: ignore [reportArgumentType]
+                        name,
+                        object_schema,
+                        [*path, str(status_code), content_type],  # pyright: ignore [reportArgumentType]
                     )
                 else:
-                    data_types[status_code][content_type] = self.get_ref_data_type(
+                    data_types[status_code][content_type] = self.get_ref_data_type(  # pyright: ignore [reportArgumentType]
                         object_schema.ref
                     )
 
@@ -499,6 +510,9 @@ class OpenAPIParser(JsonSchemaParser):
                         has_default=object_schema.has_default
                         if object_schema
                         else False,
+                        type_has_null=object_schema.type_has_null
+                        if object_schema
+                        else None,
                     )
                 )
 
@@ -508,6 +522,8 @@ class OpenAPIParser(JsonSchemaParser):
                     fields=fields,
                     reference=reference,
                     custom_base_class=self.base_class,
+                    custom_template_dir=self.custom_template_dir,
+                    keyword_only=self.keyword_only,
                 )
             )
 
@@ -590,7 +606,7 @@ class OpenAPIParser(JsonSchemaParser):
                 for (
                     obj_name,
                     raw_obj,
-                ) in schemas.items():  # type: str, Dict[Any, Any]
+                ) in schemas.items():
                     self.parse_raw_obj(
                         obj_name,
                         raw_obj,
