@@ -27,7 +27,7 @@ import pydantic
 from packaging import version
 from pydantic import StrictBool, StrictInt, StrictStr, create_model
 
-from datamodel_code_generator.format import PythonVersion
+from datamodel_code_generator.format import DatetimeClassType, PythonVersion
 from datamodel_code_generator.imports import (
     IMPORT_ABC_MAPPING,
     IMPORT_ABC_SEQUENCE,
@@ -114,25 +114,25 @@ class UnionIntFloat:
     def __get_pydantic_core_schema__(
         cls, _source_type: Any, _handler: 'GetCoreSchemaHandler'
     ) -> 'core_schema.CoreSchema':
-        from_int_schema = core_schema.chain_schema(
+        from_int_schema = core_schema.chain_schema(  # pyright: ignore [reportPossiblyUnboundVariable]
             [
-                core_schema.union_schema(
-                    [core_schema.int_schema(), core_schema.float_schema()]
+                core_schema.union_schema(  # pyright: ignore [reportPossiblyUnboundVariable]
+                    [core_schema.int_schema(), core_schema.float_schema()]  # pyright: ignore [reportPossiblyUnboundVariable]
                 ),
-                core_schema.no_info_plain_validator_function(cls.validate),
+                core_schema.no_info_plain_validator_function(cls.validate),  # pyright: ignore [reportPossiblyUnboundVariable]
             ]
         )
 
-        return core_schema.json_or_python_schema(
+        return core_schema.json_or_python_schema(  # pyright: ignore [reportPossiblyUnboundVariable]
             json_schema=from_int_schema,
-            python_schema=core_schema.union_schema(
+            python_schema=core_schema.union_schema(  # pyright: ignore [reportPossiblyUnboundVariable]
                 [
                     # check if it's an instance first before doing any further work
-                    core_schema.is_instance_schema(UnionIntFloat),
+                    core_schema.is_instance_schema(UnionIntFloat),  # pyright: ignore [reportPossiblyUnboundVariable]
                     from_int_schema,
                 ]
             ),
-            serialization=core_schema.plain_serializer_function_ser_schema(
+            serialization=core_schema.plain_serializer_function_ser_schema(  # pyright: ignore [reportPossiblyUnboundVariable]
                 lambda instance: instance.value
             ),
         )
@@ -161,7 +161,7 @@ def chain_as_tuple(*iterables: Iterable[T]) -> Tuple[T, ...]:
     return tuple(chain(*iterables))
 
 
-@lru_cache()
+@lru_cache
 def _remove_none_from_type(
     type_: str, split_pattern: Pattern[str], delimiter: str
 ) -> List[str]:
@@ -207,7 +207,7 @@ def _remove_none_from_union(type_: str, use_union_operator: bool) -> str:
     return f'{UNION_PREFIX}{UNION_DELIMITER.join(inner_types)}]'
 
 
-@lru_cache()
+@lru_cache
 def get_optional_type(type_: str, use_union_operator: bool) -> str:
     type_ = _remove_none_from_union(type_, use_union_operator)
 
@@ -236,7 +236,7 @@ class DataType(_BaseModel):
     if PYDANTIC_V2:
         # TODO[pydantic]: The following keys were removed: `copy_on_model_validation`.
         # Check https://docs.pydantic.dev/dev-v2/migration/#changes-to-config for more information.
-        model_config = ConfigDict(
+        model_config = ConfigDict(  # pyright: ignore [reportAssignmentType]
             extra='forbid',
             revalidate_instances='never',
         )
@@ -362,22 +362,21 @@ class DataType(_BaseModel):
 
     @property
     def imports(self) -> Iterator[Import]:
+        # Add base import if exists
         if self.import_:
             yield self.import_
+
+        # Define required imports based on type features and conditions
         imports: Tuple[Tuple[bool, Import], ...] = (
             (self.is_optional and not self.use_union_operator, IMPORT_OPTIONAL),
             (len(self.data_types) > 1 and not self.use_union_operator, IMPORT_UNION),
-        )
-        if any(self.literals):
-            import_literal = (
+            (
+                bool(self.literals),
                 IMPORT_LITERAL
                 if self.python_version.has_literal_type
-                else IMPORT_LITERAL_BACKPORT
-            )
-            imports = (
-                *imports,
-                (any(self.literals), import_literal),
-            )
+                else IMPORT_LITERAL_BACKPORT,
+            ),
+        )
 
         if self.use_generic_container:
             if self.use_standard_collections:
@@ -401,10 +400,13 @@ class DataType(_BaseModel):
                 (self.is_set, IMPORT_SET),
                 (self.is_dict, IMPORT_DICT),
             )
+
+        # Yield imports based on conditions
         for field, import_ in imports:
             if field and import_ != self.import_:
                 yield import_
 
+        # Propagate imports from any dict_key type
         if self.dict_key:
             yield from self.dict_key.imports
 
@@ -463,7 +465,7 @@ class DataType(_BaseModel):
             elif len(self.data_types) == 1:
                 type_ = self.data_types[0].type_hint
             elif self.literals:
-                type_ = f"{LITERAL}[{', '.join(repr(literal) for literal in self.literals)}]"
+                type_ = f'{LITERAL}[{", ".join(repr(literal) for literal in self.literals)}]'
             else:
                 if self.reference:
                     type_ = self.reference.short_name
@@ -542,6 +544,7 @@ class Types(Enum):
     binary = auto()
     date = auto()
     date_time = auto()
+    timedelta = auto()
     password = auto()
     path = auto()
     email = auto()
@@ -574,6 +577,7 @@ class DataTypeManager(ABC):
         use_non_positive_negative_number_constrained_types: bool = False,
         use_union_operator: bool = False,
         use_pendulum: bool = False,
+        target_datetime_class: Optional[DatetimeClassType] = None,
     ) -> None:
         self.python_version = python_version
         self.use_standard_collections: bool = use_standard_collections
@@ -584,6 +588,9 @@ class DataTypeManager(ABC):
         )
         self.use_union_operator: bool = use_union_operator
         self.use_pendulum: bool = use_pendulum
+        self.target_datetime_class: DatetimeClassType = (
+            target_datetime_class or DatetimeClassType.Datetime
+        )
 
         if (
             use_generic_container_types and python_version == PythonVersion.PY_36
