@@ -1,8 +1,17 @@
 from __future__ import annotations
 
 import copy
+from functools import cached_property  # noqa: F401
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Callable, Dict, TypeVar
+from typing import (  # noqa: F401
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Dict,
+    Protocol,
+    TypeVar,
+    runtime_checkable,
+)
 
 import pydantic
 from packaging import version
@@ -15,59 +24,26 @@ PYDANTIC_VERSION = version.parse(
 PYDANTIC_V2: bool = PYDANTIC_VERSION >= version.parse('2.0b3')
 
 if TYPE_CHECKING:
-    cached_property = property
+    from typing import Literal
+
     from yaml import SafeLoader
 
-    Protocol = object
-    runtime_checkable: Callable[..., Any]
-
-    from typing_extensions import Literal
-
-    def load_toml(path: Path) -> Dict[str, Any]:
-        ...
+    def load_toml(path: Path) -> Dict[str, Any]: ...
 
 else:
-    try:
-        from typing import Protocol
-    except ImportError:
-        from typing_extensions import Protocol  # noqa
-    try:
-        from typing import runtime_checkable
-    except ImportError:
-        from typing_extensions import runtime_checkable  # noqa
     try:
         from yaml import CSafeLoader as SafeLoader
     except ImportError:  # pragma: no cover
         from yaml import SafeLoader
 
     try:
-        from functools import cached_property
+        from tomllib import load as load_tomllib
     except ImportError:
-        _NOT_FOUND = object()
+        from tomli import load as load_tomllib
 
-        class cached_property:
-            def __init__(self, func: Callable) -> None:
-                self.func: Callable = func
-                self.__doc__: Any = func.__doc__
-
-            def __get__(self, instance: Any, owner: Any = None) -> Any:
-                value = instance.__dict__.get(self.func.__name__, _NOT_FOUND)
-                if value is _NOT_FOUND:  # pragma: no cover
-                    value = instance.__dict__[self.func.__name__] = self.func(instance)
-                return value
-
-    try:
-        import tomllib
-
-        def load_toml(path: Path) -> Dict[str, Any]:
-            with path.open('rb') as f:
-                return tomllib.load(f)
-
-    except ImportError:
-        import toml
-
-        def load_toml(path: Path) -> Dict[str, Any]:
-            return toml.load(path)
+    def load_toml(path: Path) -> Dict[str, Any]:
+        with path.open('rb') as f:
+            return load_tomllib(f)
 
 
 SafeLoaderTemp = copy.deepcopy(SafeLoader)
@@ -101,7 +77,7 @@ def field_validator(
     field_name: str,
     *fields: str,
     mode: Literal['before', 'after'] = 'after',
-) -> Callable[[Any], Callable[[Model, Any], Any]]:
+) -> Callable[[Any], Callable[[BaseModel, Any], Any]]:
     def inner(method: Callable[[Model, Any], Any]) -> Callable[[Model, Any], Any]:
         if PYDANTIC_V2:
             from pydantic import field_validator as field_validator_v2
@@ -123,4 +99,4 @@ else:
 
 class BaseModel(_BaseModel):
     if PYDANTIC_V2:
-        model_config = ConfigDict(strict=False)
+        model_config = ConfigDict(strict=False)  # pyright: ignore [reportAssignmentType]
